/**
 * @namespace flexygo.pda.conteo
 */
var flexygo;
(function (flexygo) {
    var pda;
    (function (pda) {
        var conteo;
        (function (conteo) {
            //GENÉRICO: El evento OnKeyUp se usa para no lanzar la acción del enter sobre los focos de botón. Es necesario un OnKeyDown sólo para el tabulador
            conteo.readKeyTab = (e, funcname, params) => {
                if (e.keyCode == 9) {
                    e.preventDefault();
                    flexygo.pda.conteo[funcname].apply(flexygo.pda.conteo, params);
                }
                else {
                    return;
                }
            };
            //GENÉRICO: Lectura de carácteres de entrada y ejecución de la función cuando se recibe ENTER
            conteo.readByCharacter = (e, funcname, params) => {
                let read = false;
                if (e.keyCode == 13) {
                    flexygo.pda.conteo[funcname].apply(flexygo.pda.conteo, params);
                }
                else {
                    return;
                }
            };
            conteo.seleccionarConteo = (IdDocDetalle) => {
                //Recibimos o un número si se llama desde la consulta de ubicaciones, o un campo si se llama desde el selector de trabajos de Conteos
                let Detalle = (typeof IdDocDetalle) == 'number' ? IdDocDetalle : IdDocDetalle.val() ? IdDocDetalle.val() : null;
                if (!Detalle) {
                    flexygo.msg.warning("No se ha seleccionado un Conteo", null, '');
                }
                else {
                    let params = [{ "Key": "IdDocDetalle", "Value": Detalle }];
                    let proc = new flexygo.Process('SGA_PDA_dll_ConteoUbicaciones_DameDatosTrabajoInventario', null, null);
                    flexygo.pda.addLock();
                    proc.run(params, (response) => {
                        if (response) {
                            if (response.JSCode) {
                                var func = new Function(response.JSCode);
                                func.call(response.JSCode);
                                flexygo.pda.removeLock();
                            }
                            if (response.LastException && response.LastException.Message) {
                                flexygo.msg.error(response.LastException.Message);
                            }
                            else if (response.WarningMessage) {
                                flexygo.msg.warning(response.WarningMessage);
                                flexygo.nav.openPageName('syspage-generic-controlpanel', '', '', null, 'main', false, null);
                            }
                            else if (response.SuccessMessage) {
                                let auxdef = {};
                                auxdef.IdDocDetalle = response.Data.IdDocDetalle;
                                auxdef.IdTrabajo = response.Data.IdTrabajo;
                                auxdef.HayBultos = response.Data.HayBultos;
                                auxdef.HayArticulos = response.Data.HayArticulos;
                                auxdef.EsCiego = response.Data.EsCiego;
                                auxdef.IdBulto = 0;
                                let strdef = JSON.stringify(auxdef);
                                flexygo.context.CodUbicLeidaInventario = undefined;
                                flexygo.nav.openPageName('SGA_PDA_pg_ConteoUbicaciones_DetalleInventario', 'SGA_PDA_Trabajo_Inventario', `IdDocDetalle = ${auxdef.IdDocDetalle}`, strdef, 'main', false);
                            }
                        }
                    });
                }
            };
            conteo.SiguienteTrabajo = (e, IdTrabajo) => {
                let module = $('flx-module')[0];
                let page = flexygo.history.get(module);
                let proc = new flexygo.Process('SGA_PDA_dll_ConteoUbicaciones_TrabajosInventarioPendientes', null, null);
                let IdDocDetalleOld = JSON.parse(page.defaults).IdDocDetalle;
                let params = [];
                if (IdTrabajo) {
                    params = [
                        { "Key": "IdTrabajo", "Value": IdTrabajo },
                        { "Key": "IdDocDetalle", "Value": 0 }
                    ];
                }
                else {
                    params = [
                        { "Key": "IdTrabajo", "Value": page ? JSON.parse(page.defaults).IdTrabajo : 0 },
                        { "Key": "IdDocDetalle", "Value": page ? JSON.parse(page.defaults).IdDocDetalle : 0 }
                    ];
                }
                flexygo.pda.addLock();
                proc.run(params, (response) => {
                    if (response) {
                        if (response.JSCode) {
                            var func = new Function(response.JSCode);
                            func.call(response.JSCode);
                            flexygo.pda.removeLock();
                        }
                        if (response.LastException && response.LastException.Message) {
                            flexygo.msg.error(response.LastException.Message);
                        }
                        else if (response.WarningMessage) {
                            flexygo.msg.warning(response.WarningMessage);
                            flexygo.nav.openPageName('syspage-generic-controlpanel', '', '', null, 'main', false, null);
                        }
                        else if (response.SuccessMessage) {
                            let auxdef = {};
                            auxdef.IdDocDetalle = response.Data.IdDocDetalle;
                            auxdef.IdTrabajo = response.Data.IdTrabajo;
                            auxdef.HayBultos = response.Data.HayBultos;
                            auxdef.HayArticulos = response.Data.HayArticulos;
                            auxdef.EsCiego = response.Data.EsCiego;
                            auxdef.IdBulto = 0;
                            let strdef = JSON.stringify(auxdef);
                            if (response.Data.IdDocDetalle == 0) {
                                flexygo.msg.success("No hay detalles pendientes en el trabajo de conteo.", null, null);
                                flexygo.nav.openPageName('SGA_PDA_pg_Conteo_Ubicacion_P', '', '', null, 'main', true, e);
                            }
                            else {
                                flexygo.nav.openPageName('SGA_PDA_pg_ConteoUbicaciones_DetalleInventario', 'SGA_PDA_Trabajo_Inventario', `IdDocDetalle = ${auxdef.IdDocDetalle}`, strdef, 'main', false, e);
                            }
                        }
                    }
                });
            };
            conteo.lecturaArticulo = (e, modDatos, modLectura) => {
                //Módulo con la información de la ubicación leída
                let Datos = $(`[modulename=${modDatos}]flx-view`)[0];
                let Lectura = $(`[modulename=${modLectura}]flx-list`)[0];
                //Parámetros
                let pbCodigo = $('flx-text[name = "pbCodigoUbicacion"]');
                let pbCombo = $('flx-dbcombo[name = "pbComboUbicacion"]');
                //Si no tiene datos no se ha introducido la ubicación
                if (!Lectura.data || Lectura.data.length == 0) {
                    flexygo.msg.warning("No ha introducido una Ubicación");
                    flexygo.pda.conteo.limpiarUbicacion();
                    return;
                }
                //Defaults de la página
                let myModule = $('flx-module')[0];
                let page = flexygo.history.get(myModule);
                let auxdef;
                try {
                    auxdef = JSON.parse(page.defaults) ? JSON.parse(page.defaults) : {};
                }
                catch (e) {
                    auxdef = {};
                }
                //No se puede seleccionar una ubicación diferente a la del trabajo
                if (Datos.data.IdUbicacion.Value != Lectura.data[0].IdUbicacion) {
                    flexygo.msg.warning("La ubicación no coincide.");
                    flexygo.pda.conteo.limpiarUbicacion();
                    return;
                }
                auxdef.IdBulto = 0;
                auxdef.IdUbicacion = pbCombo.val();
                page.defaults = JSON.stringify(auxdef);
                flexygo.nav.openPageName('SGA_PDA_pg_Conteo_LecturaArticulo', '', '', page.defaults, 'main', false, e);
            };
            conteo.lecturaBulto = (e, modDatos, modLectura) => {
                //Módulo con la información de la ubicación leída
                let Datos = $(`[modulename=${modDatos}]flx-view`)[0];
                let Lectura = $(`[modulename=${modLectura}]flx-list`)[0];
                //Parámetros
                let pbCodigo = $('flx-text[name = "pbCodigoUbicacion"]');
                let pbCombo = $('flx-dbcombo[name = "pbComboUbicacion"]');
                //Si no tiene datos no se ha introducido la ubicación
                if (!Lectura.data || Lectura.data.length == 0) {
                    flexygo.msg.warning("No ha introducido una Ubicación");
                    flexygo.pda.conteo.limpiarUbicacion();
                    return;
                }
                //Defaults de la página
                let myModule = $('flx-module')[0];
                let page = flexygo.history.get(myModule);
                let auxdef;
                try {
                    auxdef = JSON.parse(page.defaults) ? JSON.parse(page.defaults) : {};
                }
                catch (e) {
                    auxdef = {};
                }
                //No se puede seleccionar una ubicación diferente a la del trabajo
                if (Datos.data.IdUbicacion.Value != Lectura.data[0].IdUbicacion) {
                    flexygo.msg.warning("La ubicación no coincide.");
                    flexygo.pda.conteo.limpiarUbicacion();
                    return;
                }
                //Se abre la página de lectura del bulto
                auxdef.IdUbicacion = pbCombo.val();
                page.defaults = JSON.stringify(auxdef);
                flexygo.nav.openPageName('SGA_PDA_pg_Conteo_LecturaBulto', '', '', page.defaults, 'main', false, e);
            };
            conteo.tieneLotesCheckParams = (codBarras, cboArticulos, prop, lote, cantidad, parametros) => {
                let value = prop == "IdArticulo" ? cboArticulos.val() : codBarras.val();
                let read = false;
                if (parametros) {
                    if (value) {
                        for (let i = 0; i < parametros.length; i++) {
                            read = Number(parametros[i].value) == value.length ? true : false;
                        }
                        if (read) {
                            flexygo.pda.conteo.tieneLotes(codBarras, cboArticulos, prop, lote, cantidad, value);
                        }
                        else {
                            return;
                        }
                    }
                }
                else {
                    flexygo.pda.conteo.tieneLotes(codBarras, cboArticulos, prop, lote, cantidad, value);
                }
            };
            conteo.tieneLotes = (codBarras, cboArticulos, prop, lote, cantidad, value) => {
                let module = $('flx-module')[0];
                let page = flexygo.history.get(module);
                flexygo.pda.addLock();
                let articuloEnt = new flexygo.obj.Entity(`SGA_PDA_Articulo`, `${prop} = '${value}'`);
                articuloEnt.read();
                if (articuloEnt.data.IdArticulo.Value) {
                    let artLotes = articuloEnt.data['Lotes'].Value;
                    if (!artLotes) {
                        $('flx-dbcombo[id="loteProv"]').hide();
                    }
                    else {
                        $('flx-dbcombo[id="loteProv"]').show();
                    }
                    if (prop == "IdArticulo") {
                        codBarras.val(articuloEnt.data.CodBarras.Value);
                    }
                    else {
                        cboArticulos.val(articuloEnt.data.IdArticulo.Value);
                    }
                    cantidad[0].querySelector("input").focus();
                    flexygo.pda.removeLock();
                }
                else {
                    flexygo.msg.warning("No se ha encontrado el artículo");
                    cboArticulos.val(null);
                    codBarras.val(null);
                }
            };
            conteo.eliminaLectura = (e, IdDocLectura, modRefresh) => {
                if ($(IdDocLectura).val()) {
                    flexygo.msg.confirm('¿Está seguro que quiere eliminar la lectura seleccionada?', function (ret) {
                        if (ret) {
                            let proc = new flexygo.Process('SGA_PDA_dll_ConteoUbicaciones_EliminarLectura', null, null);
                            let params = [{ "Key": "IdDocLectura", "Value": $(IdDocLectura).val() }];
                            flexygo.pda.addLock();
                            proc.run(params, (response) => {
                                if (response) {
                                    if (response.JSCode) {
                                        var func = new Function(response.JSCode);
                                        func.call(response.JSCode);
                                        flexygo.pda.removeLock();
                                    }
                                    if (response.LastException && response.LastException.Message) {
                                        flexygo.msg.error(response.LastException.Message);
                                    }
                                    else if (response.WarningMessage) {
                                        flexygo.msg.warning(response.WarningMessage);
                                        flexygo.nav.openPageName('syspage-generic-controlpanel', '', '', null, 'main', false, null);
                                    }
                                    else if (response.SuccessMessage) {
                                        let list = $("#dialog").find("flx-list")[0];
                                        list.refresh();
                                        flexygo.pda.conteo.RefreshModule(modRefresh);
                                        flexygo.pda.removeLock();
                                    }
                                }
                            });
                        }
                        else {
                            return;
                        }
                    });
                }
                else {
                    flexygo.msg.warning("Selecciona una lectura");
                }
            };
            conteo.RefreshModule = (mod) => {
                let modRefresh = $(`[modulename=${mod}]`)[0];
                modRefresh.refresh();
            };
            conteo.cierraDialogLecturas = (mod) => {
                let modRefresh = $(`[modulename=${mod}]`)[0];
                $("#dialog").remove();
                modRefresh.refresh();
            };
            conteo.validarLecturaInventario = (cantidad, codBarras, idArticulo, lote, confirma, tipo) => {
                let module = $('flx-module')[0];
                let page = flexygo.history.get(module);
                let datosvalidos = true;
                if (!idArticulo.val() || !cantidad.val()) {
                    flexygo.msg.warning("Selecciona un artículo y una cantidad.");
                    return;
                }
                flexygo.pda.addLock();
                let ArtEnt = new flexygo.obj.Entity(`SGA_PDA_Articulo`, `IdArticulo = '${idArticulo.val()}'`);
                ArtEnt.read();
                if (ArtEnt.data.IdArticulo.Value != "") {
                    if (ArtEnt.data.Lotes.Value == 1 && lote.val() == null) {
                        datosvalidos = false;
                    }
                    if ($('#cboP1')[0].style.display != "none") {
                        if (ArtEnt.data.IdDefProd.Value != null && ($('#cboP1').val() == null)) {
                            datosvalidos = false;
                        }
                    }
                    if ($('#cboP2')[0].style.display != "none") {
                        if (ArtEnt.data.IdDefProd.Value != null && ($('#cboP2').val() == null)) {
                            datosvalidos = false;
                        }
                    }
                }
                if (!datosvalidos) {
                    flexygo.msg.warning("Faltan datos");
                    return;
                }
                let proc = new flexygo.Process('SGA_PDA_dll_ConteoUbicaciones_ValidaLecturaInventarioP', null, null);
                let params = [
                    { "Key": "IdTrabajo", "Value": JSON.parse(page.defaults).IdTrabajo },
                    { "Key": "IdDocDetalle", "Value": JSON.parse(page.defaults).IdDocDetalle },
                    { "Key": "IdDocLectura", "Value": JSON.parse(page.defaults).IdDocLectura ? JSON.parse(page.defaults).IdDocLectura : 0 },
                    { "Key": "CodBarras", "Value": codBarras.val() ? codBarras.val() : "" },
                    { "Key": "IdBulto", "Value": JSON.parse(page.defaults).IdBulto },
                    { "Key": "IdArticulo", "Value": idArticulo.val() },
                    { "Key": "Lote", "Value": lote.val() ? lote.val() : "" },
                    { "Key": "P1", "Value": $('#cboP1').val() ? $('#cboP1').val() : "" },
                    { "Key": "Cantidad", "Value": cantidad.val() },
                    { "Key": "P2", "Value": $('#cboP2').val() ? $('#cboP2').val() : "" },
                ];
                proc.run(params, (response) => {
                    if (response) {
                        if (response.JSCode) {
                            var func = new Function(response.JSCode);
                            func.call(response.JSCode);
                            flexygo.pda.removeLock();
                        }
                        if (response.LastException && response.LastException.Message) {
                            flexygo.msg.error(response.LastException.Message);
                        }
                        else if (response.WarningMessage) {
                            flexygo.msg.warning(response.WarningMessage);
                            flexygo.nav.openPageName('syspage-generic-controlpanel', '', '', null, 'main', false, null);
                        }
                        else if (response.SuccessMessage) {
                            if (confirma) {
                                flexygo.nav.openPageName('SGA_PDA_pg_ConteoUbicaciones_DetalleInventario', 'SGA_PDA_Trabajo_Inventario', `IdDocDetalle = ${JSON.parse(page.defaults).IdDocDetalle}`, page.defaults, 'main', true, cantidad);
                            }
                            else {
                                let modRefresh;
                                let modRefresh2;
                                let modRefresh3 = $(`[modulename=SGA_PDA_m_ArticuloSeleccionado]flx-list`)[0];
                                if (tipo == "bulto") {
                                    modRefresh = $(`[modulename=SGA_PDA_m_Conteo_LecturaBulto]`)[0];
                                }
                                else {
                                    modRefresh = $(`[modulename=SGA_PDA_m_Conteo_LecturaArticulo]`)[0];
                                }
                                modRefresh2 = $(`[modulename=SGA_PDA_ConteoUbicaciones_CantidadStock]`)[0];
                                modRefresh.refresh();
                                modRefresh2.refresh();
                                modRefresh3.additionalWhere = "1 = 0";
                                modRefresh3.init();
                            }
                            flexygo.pda.removeLock();
                        }
                    }
                });
            };
            conteo.dameBultosPropuestos = (codBulto) => {
                let module = $('flx-module')[0];
                let page = flexygo.history.get(module);
                let proc = new flexygo.Process('SGA_PDA_dll_ConteoUbicaciones_DameBultosPropuestos', null, null);
                let params = [{ "Key": "IdDocDetalle", "Value": JSON.parse(page.defaults).IdDocDetalle }];
                flexygo.pda.addLock();
                proc.run(params, (response) => {
                    if (response) {
                        if (response.JSCode) {
                            var func = new Function(response.JSCode);
                            func.call(response.JSCode);
                            flexygo.pda.removeLock();
                        }
                        if (response.LastException && response.LastException.Message) {
                            flexygo.msg.error(response.LastException.Message);
                        }
                        else if (response.WarningMessage) {
                            flexygo.msg.warning(response.WarningMessage);
                        }
                        else if (response.SuccessMessage) {
                            if (response.Data.CodigoBulto) {
                                flexygo.msg.confirm(`Matrícula propuesta: ${response.Data.CodigoBulto}. ¿Confirmar?`, function (ret) {
                                    if (ret) {
                                        $("#CodBulto").val(response.Data.CodigoBulto);
                                        $("#CodBulto").find('input').trigger('input');
                                    }
                                });
                            }
                            flexygo.pda.removeLock();
                        }
                    }
                });
            };
            conteo.validarBulto = (item, modName, modType, foco, event) => {
                //Parámetros
                let parametros = $(`.param`);
                let pbCodigo = $('flx-text[name = "pbCodigoBulto"]');
                let pbCombo = $('flx-dbcombo[name = "pbComboBulto"]');
                let esCampoTexto = item.tagName ? (((item.tagName).toLowerCase() == "flx-text") ? true : false) : (((item[0].tagName).toLowerCase() == "flx-text") ? true : false);
                //Valor de búsqueda del campo de texto o del combo
                let valorBusqueda = esCampoTexto ? pbCodigo.val() : pbCombo.val();
                if (!valorBusqueda) {
                    return;
                }
                ;
                //Defaults de la página
                let myModule = $('flx-module')[0];
                let page = flexygo.history.get(myModule);
                let auxdef;
                try {
                    auxdef = JSON.parse(page.defaults) ? JSON.parse(page.defaults) : {};
                }
                catch (e) {
                    auxdef = {};
                }
                //Campo que indica si la lectura se ha llevado a cabo
                let read = false;
                //Si ha cambiado el valor del combo. Evitamos lanzar la búsqueda con el mismo valor.
                if (auxdef.valorBusqueda != valorBusqueda) {
                    //En caso de recibir parámetro con longitudes a tener en cuenta, y se trata del campo de texto, se verifica si se ha legeado al tamaño del parámetro
                    read = parametros ? (esCampoTexto ? flexygo.pda.readCode(parametros, valorBusqueda, event) : true) : true;
                }
                //Si damos la entrada como buena
                if (read) {
                    flexygo.pda.addLock();
                    //Recuperamos el código para aquellos casos que introduzcan el bulto. Necesario porque el proceso de búsqueda rellena la tabla temporal con la descripción
                    if (!esCampoTexto) {
                        let BultoEnt = new flexygo.obj.Entity(`SGA_PDA_BULTOS`, `IdBulto = ${valorBusqueda}`);
                        BultoEnt.read();
                        valorBusqueda = (BultoEnt.data.CodBarras1.Value) ? BultoEnt.data.CodBarras1.Value : valorBusqueda;
                    }
                    //Debo validar este bulto y buscar si ese codigo de barras existe entre todos los que hay
                    let proc = new flexygo.Process('SGA_PDA_dll_ConteoUbicaciones_BultoBuscarCodBarras', null, null);
                    let params = [{ "Key": "CodBulto", "Value": valorBusqueda }];
                    //Ejecución del proceso de búsqueda
                    proc.run(params, (response) => {
                        if (response) {
                            if (response.JSCode) {
                                var func = new Function(response.JSCode);
                                func.call(response.JSCode);
                                flexygo.pda.removeLock();
                            }
                            if (response.LastException && response.LastException.Message) {
                                flexygo.msg.error(response.LastException.Message);
                            }
                            else if (response.WarningMessage) {
                                flexygo.msg.warning(response.WarningMessage);
                            }
                            else if (response.SuccessMessage) {
                                if (Number(response.Data.IdBulto) == 0) {
                                    auxdef.IdBulto = 0;
                                    page.defaults = JSON.stringify(auxdef);
                                    flexygo.msg.confirm(`Bulto no existente, ¿desea darlo de alta?`, function (ret) {
                                        if (ret) {
                                            flexygo.msg.warning("Contenido añadido en futuro DLC");
                                        }
                                        else {
                                            flexygo.msg.warning("Código no encontrado");
                                            pbCodigo.val(null);
                                            pbCodigo[0].querySelector("input").disabled = false;
                                        }
                                    });
                                }
                                else {
                                    flexygo.pda.removeLock();
                                    auxdef.IdBulto = response.Data.IdBulto;
                                    page.defaults = JSON.stringify(auxdef);
                                    if (esCampoTexto && pbCombo[0]) {
                                        pbCombo.val(response.Data.IdBulto);
                                    }
                                    else {
                                        pbCodigo.val(response.Data.CodBulto);
                                    }
                                    pbCodigo[0].querySelector("input").disabled = true;
                                }
                                if (foco) {
                                    if (foco[0].tagName) {
                                        switch (foco[0].tagName.toLowerCase()) {
                                            case 'flx-text':
                                                foco[0].querySelector('input').focus();
                                                foco[0].querySelector('input').select();
                                                break;
                                            case 'button':
                                                foco[0].focus();
                                                break;
                                            default:
                                        }
                                    }
                                    else {
                                        switch ($(foco)[0].tagName.toLowerCase()) {
                                            case 'flx-text':
                                                $(foco)[0].querySelector('input').focus();
                                                $(foco)[0].querySelector('input').select();
                                                break;
                                            case 'button':
                                                $(foco)[0].focus();
                                                break;
                                            default:
                                        }
                                    }
                                }
                            }
                        }
                    });
                }
            };
            conteo.confirmarTrabajo = (e, selected) => {
                let module = $(`[modulename=${selected}]flx-list`)[0];
                let page = flexygo.history.get(module);
                if (module.data && module.data.length > 0) {
                    let Cuenta;
                    Cuenta = parseInt($('#badge').text());
                    if (Cuenta == 0) {
                        flexygo.msg.confirm('¿No existen lecturas desea continuar?', function (ret) {
                            if (ret) {
                                let proc = new flexygo.Process('SGA_PDA_dll_ConteoUbicaciones_ConfirmarTrabajo', null, null);
                                let params = [
                                    { "Key": "IdDocDetalle", "Value": JSON.parse(page.defaults).IdDocDetalle }
                                ];
                                flexygo.pda.addLock();
                                proc.run(params, (response) => {
                                    if (response) {
                                        if (response.JSCode) {
                                            var func = new Function(response.JSCode);
                                            func.call(response.JSCode);
                                            flexygo.pda.removeLock();
                                        }
                                        if (response.LastException && response.LastException.Message) {
                                            flexygo.msg.error(response.LastException.Message);
                                        }
                                        else if (response.WarningMessage) {
                                            flexygo.msg.warning(response.WarningMessage);
                                        }
                                        else if (response.SuccessMessage) {
                                            flexygo.context.CodUbicLeidaInventario = undefined;
                                            flexygo.pda.removeLock();
                                            flexygo.pda.conteo.SiguienteTrabajo(e, null);
                                        }
                                    }
                                });
                            }
                            else {
                                return;
                            }
                        });
                    }
                    else if (Cuenta > 0) {
                        let proc = new flexygo.Process('SGA_PDA_dll_ConteoUbicaciones_ConfirmarTrabajo', null, null);
                        let params = [
                            { "Key": "IdDocDetalle", "Value": JSON.parse(page.defaults).IdDocDetalle }
                        ];
                        flexygo.pda.addLock();
                        proc.run(params, (response) => {
                            if (response) {
                                if (response.JSCode) {
                                    var func = new Function(response.JSCode);
                                    func.call(response.JSCode);
                                    flexygo.pda.removeLock();
                                }
                                if (response.LastException && response.LastException.Message) {
                                    flexygo.msg.error(response.LastException.Message);
                                }
                                else if (response.WarningMessage) {
                                    flexygo.msg.warning(response.WarningMessage);
                                }
                                else if (response.SuccessMessage) {
                                    flexygo.context.CodUbicLeidaInventario = undefined;
                                    flexygo.pda.removeLock();
                                    flexygo.pda.conteo.SiguienteTrabajo(e, null);
                                }
                            }
                        });
                    }
                }
                else {
                    flexygo.msg.warning("Confirma lectura de ubicación");
                }
            };
            conteo.cargaCodigoUbic = (codUbic) => {
                let module = $('flx-module')[0];
                let page = flexygo.history.get(module);
                if (!JSON.parse(page.defaults).CodigoUbicacion) {
                    let auxdef = JSON.parse(page.defaults);
                    auxdef.CodigoUbicacion = codUbic.val();
                    let strdef = JSON.stringify(auxdef);
                    page.defaults = strdef;
                    flexygo.context.CodUbicLeidaInventario = codUbic.val();
                }
            };
            conteo.checkCodUbic = (inptCodUbic) => {
                if (flexygo.context.CodUbicLeidaInventario) {
                    inptCodUbic.val(flexygo.context.CodUbicLeidaInventario);
                    flexygo.pda.leerItemParametros(inptCodUbic, 'SGA_PDA_m_Conteo_LecturaUbicacionSeleccionada', 'flx-list', 'Codigo', $('.param'), $('#Nivel'));
                }
            };
            conteo.limpiarCampos = () => {
                //Campos de artículo
                $("#CodBarras").val(null);
                $("#cboArticulos").val(null);
                //Módulo artículo seleccionado
                let modRefresh = $(`[modulename=SGA_PDA_m_ArticuloSeleccionado]flx-list`)[0];
                modRefresh.additionalWhere = "1 = 0";
                modRefresh.init();
                //Campos de proveedor
                $("#loteProv").val(null);
                $('#loteProv').hide();
                //Combos Propiedades
                $('#cboP1').hide();
                $('#cboP1').val(null);
                $('#cboP2').hide();
                $('#cboP2').val(null);
                //Campos de cantidades y tipos de unidad
                $("#cantidad").val(null);
                $("#cboUnidades").val(null);
                $("#cantidadStock").val(null);
                $("#unidadStock").val(null);
                //Defaults de la página
                let myModule = $('flx-module')[0];
                let page = flexygo.history.get(myModule);
                let auxdef;
                try {
                    auxdef = JSON.parse(page.defaults) ? JSON.parse(page.defaults) : {};
                }
                catch (e) {
                    auxdef = {};
                }
                auxdef.valorBusqueda = "";
                page.defaults = JSON.stringify(auxdef);
                //Foco
                $("#CodBarras")[0].querySelector("input").focus();
            };
            conteo.limpiarBulto = () => {
                flexygo.pda.conteo.limpiarCampos();
                if (!$("#cboBulto")[0].classList.contains("hidden")) {
                    $("#cboBulto")[0].classList.add("hidden");
                }
                ;
                $("#cboBulto").val(null);
                if ($("#CodBulto").length > 0) {
                    $("#CodBulto").val(null);
                    $("#CodBulto")[0].querySelector("input").disabled = false;
                }
                $("#CodBulto")[0].querySelector("input").focus();
            };
            conteo.limpiarUbicacion = () => {
                //Campos de ubicación
                $("#CodUbic").val(null);
                $("#cboUbicaciones").val(null);
                //Módulo lectura seleccionada
                let modRefresh = $(`[modulename=SGA_PDA_m_Conteo_LecturaUbicacionSeleccionada]flx-list`)[0];
                modRefresh.additionalWhere = "1 = 0";
                modRefresh.init();
                //Defaults de la página
                let myModule = $('flx-module')[0];
                let page = flexygo.history.get(myModule);
                let auxdef;
                try {
                    auxdef = JSON.parse(page.defaults) ? JSON.parse(page.defaults) : {};
                }
                catch (e) {
                    auxdef = {};
                }
                auxdef.valorBusqueda = "";
                page.defaults = JSON.stringify(auxdef);
                //Limpiamos el nivel
                flexygo.pda.ubicacion.LoadBadgeNivel("0");
                //Ubicación leída
                flexygo.context.CodUbicLeidaInventario = undefined;
                //Foco
                $("#CodUbic")[0].querySelector("input").focus();
            };
            conteo.dameBultosPorUbicacion = () => {
                let module = $('flx-module')[0];
                let page = flexygo.history.get(module);
                let IdUbicacion = JSON.parse(page.defaults).IdUbicacion ? JSON.parse(page.defaults).IdUbicacion : '';
                let modName = $(`[modulename=SGA_PDA_m_Conteo_LecturaBultoPorUbicacion]flx-html`)[0];
                modName.additionalWhere = "IdUbicacion = " + IdUbicacion;
                modName.refresh();
            };
            conteo.sinTrabajos = () => {
                if ($("#SinTrabajos").length > 0) {
                    flexygo.msg.success("No hay trabajos de conteo pendientes.", null, null);
                    flexygo.nav.goHome();
                }
            };
            //Lectura de artículo en conteo de bulto
            conteo.LeerCodigosArticuloPicking = (item, modName, modType, event) => {
                //Parámetros y campos
                let parametros = $(`.param`);
                let pbCodigo = $('flx-text[name = "pbCodArticulo"]');
                let pbCombo = $('flx-dbcombo[name = "pbComboArticulo"]');
                let pbLote = $('flx-dbcombo[name = "pbComboLote"]');
                let pbCantidad = $('flx-text[name = "pbCantidad"]');
                let pbComboUnidades = $('flx-dbcombo[name = "pbComboUnidades"]');
                let pbCantidadStock = $('flx-text[name = "pbCantidadStock"]');
                let pbUnidadStock = $('flx-text[name = "pbUnidadStock"]');
                let pbStock = $('flx-text[name = "pbStock"]');
                let pbComboP1 = $('flx-dbcombo[name = "pbComboP1"]');
                let pbComboP2 = $('flx-dbcombo[name = "pbComboP2"]');
                //Valor de búsqueda del campo de texto o del combo
                let valorBusqueda = ((item.tagName).toLowerCase() == "flx-text") ? pbCodigo.val() : pbCombo.val();
                if (!valorBusqueda) {
                    return;
                }
                ;
                //Defaults de la página
                let myModule = $('flx-module')[0];
                let page = flexygo.history.get(myModule);
                let auxdef;
                try {
                    auxdef = JSON.parse(page.defaults) ? JSON.parse(page.defaults) : {};
                }
                catch (e) {
                    auxdef = {};
                }
                //Campo que indica si la lectura se ha llevado a cabo
                let read = false;
                //Si ha cambiado el valor del combo. Evitamos lanzar la búsqueda con el mismo valor.
                if (auxdef.valorBusqueda != valorBusqueda) {
                    //En caso de recibir parámetro con longitudes a tener en cuenta, y se trata del campo de texto, se verifica si se ha legeado al tamaño del parámetro
                    read = parametros ? (((item.tagName).toLowerCase() == "flx-text") ? flexygo.pda.readCode(parametros, valorBusqueda, event) : true) : true;
                }
                //Si damos la entrada como buena
                if (read) {
                    flexygo.pda.addLock();
                    let articulo = flexygo.pda.articulo.Buscar(valorBusqueda);
                    articulo.then(function (datos) {
                        //No encontrado
                        if (!datos.IdArticulo) {
                            flexygo.msg.warning("No se ha encontrado ningún artículo.");
                            flexygo.pda.conteo.limpiarCampos();
                            return;
                        }
                        //Módulo con datos del artículo leído
                        let module = $('flx-module')[0];
                        let page = flexygo.history.get(module);
                        let modLectura = $(`[modulename=${modName}]${modType}`)[0];
                        modLectura.additionalWhere = `IdArticulo = '${datos.IdArticulo}'`;
                        modLectura.init();
                        //TRATAMOS LOTES
                        //Si recibimos lote interno lo cargamos y ocultamos el combo
                        if (datos.LoteInterno) {
                            pbLote.val(datos.LoteInterno);
                            pbLote.hide();
                        }
                        //Ocultamos o mostramos combo según artículo
                        if (!datos.RequiereLote) {
                            pbLote.hide();
                        }
                        else {
                            pbLote.show();
                            //si recibimos el lote lo cargamos
                            if (datos.Lote) {
                                pbLote.val(datos.Lote);
                            }
                        }
                        //TRATAMOS PROPIEDADES
                        //----------------------------------
                        //Ocultamos/Mostramos los combos y cargamos la propiedad recibida
                        datos.RequiereP1 ? pbComboP1.show() : pbComboP1.hide();
                        datos.RequiereP2 ? pbComboP2.show() : pbComboP2.hide();
                        if (datos.RequiereP1 && datos.P1) {
                            pbComboP1.val(datos.P1);
                        }
                        ;
                        if (datos.RequiereP2 && datos.P2) {
                            pbComboP2.val(datos.P2);
                        }
                        ;
                        //Valores de campos de búsqueda
                        if ((item.tagName).toLowerCase() == "flx-dbcombo") {
                            //Evento lanzado por el combo
                            valorBusqueda = datos.IdArticulo;
                            pbCodigo.val(valorBusqueda);
                        }
                        else {
                            //Evento lanzado por el campo de texto, se establece el ID en el combo
                            pbCombo.val(datos.IdArticulo);
                        }
                        //Valor de búsqueda para no repetir acción si no cambia
                        auxdef.valorBusqueda = valorBusqueda;
                        page.defaults = JSON.stringify(auxdef);
                        //Se recupera el valor por defecto del tipo de unidad de artículo
                        let tipoUnidad = flexygo.pda.articulo.TipoUnidad(datos.IdArticulo, pbLote.val() ? pbLote.val() : "");
                        tipoUnidad.then(function (tipo) {
                            //Tipos de Unidades del artículo para conversiones
                            pbComboUnidades[0].additionalWhere = `IdArticulo = '${datos.IdArticulo}'`;
                            pbComboUnidades[0].refresh();
                            pbComboUnidades[0].querySelector("input").disabled = false;
                            if (tipo) {
                                pbComboUnidades.val(tipo);
                                pbUnidadStock.val(tipo);
                                pbCantidadStock.val(null);
                            }
                            //Focos
                            flexygo.pda.setAutomaticFocus(item);
                        });
                        tipoUnidad.catch(function (error) {
                            if (error && error != "") {
                                flexygo.msg.warning(error);
                                return;
                            }
                        });
                    });
                    articulo.catch(function (error) {
                        if (error && error != "") {
                            flexygo.msg.warning(error);
                            return;
                        }
                    });
                    flexygo.pda.removeLock();
                }
            };
            //Combo de lotes. Efecto de pérdida de foco 
            conteo.checkLote = (item, event) => {
                //Campos a comprobar
                let pbComboP1 = $('flx-dbcombo[name = "pbComboP1"]:visible');
                let pbComboP2 = $('flx-dbcombo[name = "pbComboP2"]:visible');
                let pbCantidad = $('flx-dbcombo[name = "pbCantidad"]');
                //Foco
                flexygo.pda.setAutomaticFocus(item);
            };
            //Conversión de stock/unidades
            conteo.dameStockUnidades = (codBarras, cboArticulos, prop, idUbicacion, lote, stock, cantidad, parametros, cboUnidades, unidadStock, cantidadStock, cboEmbalajes, bultos, foco) => {
                let module = $('flx-module')[0];
                let page = flexygo.history.get(module);
                if (cboArticulos.val() && cboUnidades.val()) {
                    flexygo.pda.addLock();
                    if (cantidad.val()) {
                        let proc = new flexygo.Process('SGA_PDA_dll_DameStockUnidades', null, null);
                        let params = [{ 'Key': 'IdArticulo', 'Value': cboArticulos.val() }, { 'Key': 'NumLote', 'Value': lote ? lote.val() : "" }, { 'Key': 'IdEmbalaje', 'Value': cboEmbalajes ? cboEmbalajes.val() : "" }, { 'Key': 'Unidad_Leida', 'Value': cboUnidades.val() }, { 'Key': 'Cantidad_Leida', 'Value': cantidad.val() }];
                        proc.run(params, (response) => {
                            if (response) {
                                if (response.JSCode) {
                                    var func = new Function(response.JSCode);
                                    func.call(response.JSCode);
                                    flexygo.pda.removeLock();
                                }
                                if (response.LastException && response.LastException.Message) {
                                    flexygo.msg.error(response.LastException.Message);
                                }
                                else if (response.WarningMessage) {
                                    flexygo.msg.warning(response.WarningMessage);
                                }
                                else if (response.SuccessMessage) {
                                    cantidadStock.val(response.Data["Cantidad_Stock"]);
                                    if (bultos) {
                                        bultos.val(response.Data["NumBultos"]);
                                    }
                                    if (foco) {
                                        if (foco[0].tagName) {
                                            switch (foco[0].tagName.toLowerCase()) {
                                                case 'flx-text':
                                                    foco[0].querySelector('input').focus();
                                                    foco[0].querySelector('input').select();
                                                    break;
                                                case 'button':
                                                    foco[0].focus();
                                                    break;
                                                default:
                                            }
                                        }
                                        else {
                                            switch ($(foco)[0].tagName.toLowerCase()) {
                                                case 'flx-text':
                                                    $(foco)[0].querySelector('input').focus();
                                                    $(foco)[0].querySelector('input').select();
                                                    break;
                                                case 'button':
                                                    $(foco)[0].focus();
                                                    break;
                                                default:
                                            }
                                        }
                                    }
                                }
                            }
                            flexygo.pda.removeLock();
                        });
                    }
                    else {
                        flexygo.msg.warning("Selecciona una cantidad");
                    }
                }
                else {
                    flexygo.msg.warning("Selecciona un artículo y una unidad");
                }
            };
        })(conteo = pda.conteo || (pda.conteo = {}));
    })(pda = flexygo.pda || (flexygo.pda = {}));
})(flexygo || (flexygo = {}));
//# sourceMappingURL=conteo.js.map