/**
 * @namespace flexygo.pda
 */
var flexygo;
(function (flexygo) {
    var pda;
    (function (pda) {
        //GENÉRICO: El evento OnKeyUp se usa para no lanzar la acción del enter sobre los focos de botón. Es necesario un OnKeyDown sólo para el tabulador
        pda.readKeyTab = (e, funcname, params) => {
            if (e.keyCode == 9) {
                e.preventDefault();
                flexygo.pda[funcname].apply(flexygo.pda, params);
            }
            else {
                return;
            }
        };
        //GENÉRICO: Leer carácter y lanzar función en caso de encontrarlo
        pda.readByCharacter = (e, funcname, params) => {
            if (e.keyCode == 13) {
                flexygo.pda[funcname].apply(flexygo.pda, params);
            }
            else {
                return;
            }
        };
        //GENÉRCIO: Incialización del teclado en pantalla. Lanzado desde módulo MAIN_HEADER
        pda.initTeclado = () => {
            flexygo.context.keyboardoff = true;
        };
        //GENÉRICO: Cambiar la visualización de los componentes del menú adicional 
        pda.toggleMenu = () => {
            if ($('.menu-item').length > 0) {
                $('.menu-item').eq(0).toggleClass('menu-item-1', 100);
                $('.menu-item').eq(0).toggleClass('hidden', 0);
                $('.menu-item').eq(1).toggleClass('menu-item-2', 200);
                $('.menu-item').eq(1).toggleClass('hidden', 0);
                $('.menu-item').eq(2).toggleClass('menu-item-3', 300);
                $('.menu-item').eq(2).toggleClass('hidden', 0);
            }
        };
        //GENÉRICO: Establece las variables de contexto en el cliente tras loguearse en la PDA.
        pda.afterLogin = (docsesion, almacen, terminal, maquina, descrip, tipomaq, subtipomaq) => {
            //Asignación variables de contexto
            flexygo.context.currentIdDocSesion = docsesion;
            flexygo.context.currentAlmacen = almacen;
            flexygo.context.currentTerminal = terminal;
            flexygo.context.currentMaquina = maquina;
            flexygo.context.currentNombreMaquina = descrip;
            flexygo.context.currentTipoMaquina = tipomaq;
            flexygo.context.currentSubtipoMaquina = subtipomaq;
            flexygo.nav.openPageName('syspage-generic-controlpanel', '', '', null, 'main', false, null);
        };
        //GENÉRICO: Foco automático por tabindex en controles de módulos/página
        pda.setAutomaticFocus = (item) => {
            //Solo gestionamos los focos de elementos con tabindex declarados
            if (item && !item.tabIndex) {
                return;
            }
            let tabIndex = item ? parseInt(item.tabIndex) : 0;
            //Controles con Tabindex
            $("flx-module").find('[tabindex]').each(function () {
                let elemento = $(this)[0];
                if (elemento && elemento.attributes.tabindex) {
                    //Tabindex del elemento
                    let index = parseInt(elemento.attributes.tabindex.value);
                    //Si es mayor se verifica si puede recibir el foco
                    if (index > tabIndex) {
                        //Aplicamos el foco si el control es visible y no tiene valor.
                        if ($(elemento).attr("style") != 'display: none;' && !$(elemento)[0].querySelector('.hidden') && !$(elemento).val()) {
                            if (elemento.querySelector('input')) {
                                elemento.querySelector('input').focus();
                            }
                            else {
                                elemento.focus();
                            }
                            elemento.animate({ scrollTop: 0 }, 300);
                            return false;
                        }
                    }
                }
            });
        };
        //GENÉRICO: Obtiene el texto o icono de la cabecera de la página
        pda.getHeaderText = () => {
            $('#mainLogo')[0].innerText = '';
            $('#mainLogo').css('background-image', 'none');
            //let mod: any = $('flx-module')[0];
            let pageProperties = flexygo.history.get($('main'));
            if (!pageProperties.pagename) {
                let logo = document.createElement("IMG");
                $(logo).addClass('datosImagen');
                $('#mainLogo')[0].appendChild(logo);
            }
            else {
                if (pageProperties.pagename === flexygo.profiles.startuppage) {
                    $('#mainLogo')[0].innerHTML = "<b style='font-size:13px'>" + flexygo.context.currentNombreMaquina + "</b>";
                }
                else {
                    $('#mainLogo')[0].innerHTML = "<b style='font-size:17px'>" + pageProperties.description + "</b>";
                }
            }
        };
        //GENÉRICO: carga los parámetros de configuración de la PDA
        pda.loadParametros = (params) => {
            //Carga parámetros y valor del mismo
            for (let i = 0; i < params.length; i++) {
                let parametroEnt = new flexygo.obj.Entity(`SGA_PDA_Configuracion`, `Parametro = '${params[i].id}'`);
                parametroEnt.read();
                params[i].value = parametroEnt.data.Valor.Value;
            }
        };
        //GENÉRICO: Navegación a patalla principal
        pda.goHome = () => {
            flexygo.context.CodUbicLeidaInventario = undefined;
            flexygo.nav.goHome();
        };
        //GENÉRICO: muestra y oculta los combos asociados a los cuadros de texto de búsqueda.
        pda.showHideCombo = (cont) => {
            cont[0].classList.contains("hidden") ? cont[0].classList.remove("hidden") : cont[0].classList.add("hidden");
        };
        //GENÉRICO: crea el diálogo lanzado por los contadores.
        pda.createDialogList = (badge, modName, modType, title, hideButtons, campoWhere, campoProp) => {
            if ($("#dialog")) {
                $("#dialog").remove();
            }
            $("body").append(`<div class='d-none customDialog' id='dialog' title='${title}'></div>`);
            let module = $(`[modulename=${modName}]${modType}`)[0];
            let clone = module.cloneNode();
            if (campoWhere) {
                let moduleParent = $('flx-module')[0];
                let page = flexygo.history.get(moduleParent);
                let valor = JSON.parse(page.defaults)[campoProp] ? JSON.parse(page.defaults)[campoProp] : 0;
                clone.additionalWhere = `${campoWhere} = '${valor}'`;
                ;
            }
            document.body.querySelector("#dialog").appendChild(clone);
            clone.init();
            $('#dialog').switchClass("d-none", "d-block");
            $('#dialog').dialog({
                minWidth: 300,
                width: $("#mainContent").width(),
                position: ['center', 20],
                maxHeight: $("#mainContent").height(),
            });
            if (hideButtons) {
                setTimeout(() => {
                    $('#dialog')[0].querySelector(".botoneraHorizontal").classList.add("hidden");
                }, 1000);
            }
        };
        //GENÉRICO: Carga de valos de los contadores
        pda.loadBadgeValue = (badge, campo, tabla, campoWhere, campoProp) => {
            let module = $('flx-module')[0];
            let page = flexygo.history.get(module);
            let valor = JSON.parse(page.defaults)[campoProp] ? JSON.parse(page.defaults)[campoProp] : 0;
            let proc = new flexygo.Process('SGA_PDA_dll_CuentaRegistrosConsultas', null, null);
            let params = [
                { "Key": "Campo", "Value": campo },
                { "Key": "Tabla", "Value": tabla },
                { "Key": "CampoWhere", "Value": campoWhere },
                { "Key": "Valor", "Value": valor }
            ];
            proc.run(params, (response) => {
                if (response) {
                    if (response.JSCode) {
                        var func = new Function(response.JSCode);
                        func.call(response.JSCode);
                    }
                    if (response.LastException && response.LastException.Message) {
                        flexygo.msg.error(response.LastException.Message);
                    }
                    else if (response.WarningMessage) {
                    }
                    else if (response.SuccessMessage) {
                        badge.text(response.Data.count);
                    }
                }
            });
        };
        //GENÉRICO: valida que el valor introducido coincida con alguno de los parámetros de tamaño (bulto, ean, dun) de los módulos.
        pda.readCode = (params, value, event) => {
            let read = false;
            if (params) {
                let sel = params.toArray().filter((param) => {
                    return param.id == "Lectura_Caracter" && param.value == "ON";
                });
                //si está activo el parámetro Lectura_Caracter, al recibir un TAB o ENTER se da por leído
                if (sel.length > 0 && event.keyCode) {
                    if (event.keyCode == 9 || event.keyCode == 13) {
                        read = true;
                    }
                    else {
                        read = false;
                    }
                }
                //Si la comprobación anterior no devuelve read (no está activo el parámetro, o no se ha recibido TAB o ENTER), se sigue hasta que se llegue al límite del parámetro correspondiente
                if (!read) {
                    for (let i = 0; i < params.length; i++) {
                        if (Number(params[i].value) == value.length) {
                            read = true;
                        }
                    }
                }
            }
            else {
                read = true;
            }
            return read;
        };
        //GENÉRICO: inicia el spinner
        pda.addLock = () => {
            $("#mainContent").append('<div style="position:absolute;z-index:60;top:0px;bottom:0px;left:0px;right:0px;background-color:rgba(255,255,255,0.5);" class="lockDiv"><div class="lds-roller"><div></div><div></div><div></div><div></div><div></div><div></div><div></div><div></div></div>');
            $("#mainContent").closest('.cntBody').css('position', 'relative');
            setTimeout(function () {
                flexygo.pda.removeLock();
            }, 10000);
        };
        //GENÉRICO: elimina el spinner
        pda.removeLock = () => {
            $("#mainContent").closest('.cntBody').css('position', '');
            $("#mainContent").find('.lockDiv').remove();
        };
        //GENÉRICO: conversor de fecha
        pda.convertDate = (val) => {
            val = val.match(/\d+/)[0];
            let valN = val.match(/\d+/)[0] * 1;
            return moment(new Date(val.match(/\d+/)[0] * 1)).format('LLL');
        };
        //GENÉRICO: elimina los negativos de una cantidad
        pda.positiveAmount = (element) => {
            element.val(element.val().replace("-", ""));
        };
        //GENÉRICO: intercambia entre clases de tipo css de un elemento HTML
        pda.swapClasses = (classRemove, classAdd, element) => {
            element.removeClass(classRemove);
            element.addClass(classAdd);
        };
        //GENÉRICO: refresca los módulos recibidos
        pda.refreshModules = (modules) => {
            modules.map((mod) => {
                let module = $(`[modulename=${mod.modName}]${mod.modType}`)[0];
                module.refresh();
            });
        };
        //GENÉRICO: refresca todos los módulos de la página que contiene el elemento que lanza el comando
        pda.refreshPageModules = (triggerElement) => {
            let cnt = triggerElement.closest('.pageContainer');
            let parent = cnt.data('opener');
            let modCol = null;
            if (parent) {
                modCol = parent;
            }
            else {
                modCol = cnt;
            }
            modCol.find('flx-module').each((i, e) => {
                let mod = $(e);
                let wc = mod[0];
                if (wc.refresh) {
                    wc.refresh();
                }
            });
        };
        //GENÉRICO: habilita y deshabilita los botones
        pda.enableButtons = (enable, disable) => {
            $(`#${enable}`).show();
            $(`#${disable}`).hide();
            let cboArticulos = $('flx-dbcombo[id="cboArticulos"]');
            if (enable == "primary") {
                cboArticulos.attr('disabled', false);
            }
            else {
                cboArticulos.attr('disabled', true);
            }
        };
        //GENÉRICO: efecto de selección de las listas de PDA cambiando la clase css asociada.
        pda.toggleClassSelectionListPDA = (parent, classRemove, element, classDestiny) => {
            parent.find("div").each(function () {
                let divider = $(this);
                if (divider.attr("togglelist") == "list") {
                    divider.removeClass(classDestiny);
                    divider.addClass(classRemove);
                }
            });
            $(element).toggleClass(classDestiny.concat(' ', classRemove));
        };
        //GENÉRICO: vacía campos e inicializa el módulo con Where a 1 = 0
        pda.limpiarFiltro = (item, modName, modType, pageDefaults) => {
            let arrItems = item.split(",");
            let Max = arrItems.length;
            for (var i = 0; i < Max; i++) {
                if ($(arrItems[i])[0].tagName == "FLX-DBCOMBO") {
                    let flxdbcombo = $(arrItems[i])[0];
                    flxdbcombo.additionalWhere = null;
                    flxdbcombo.refresh();
                }
                $(arrItems[i]).val(null);
            }
            $(arrItems[0]).find("input").focus();
            if (modName) {
                let arrmodName = modName.split(",");
                let Max2 = arrmodName.length;
                for (var i = 0; i < Max2; i++) {
                    let module = $(`[modulename=${arrmodName[i]}]${modType}`)[0];
                    module.additionalWhere = "1 = 0";
                    module.init();
                }
            }
            if (pageDefaults) {
                let arrDefaults = pageDefaults.split(",");
                let Max3 = arrDefaults.length;
                let myModule = $('flx-module')[0];
                let page = flexygo.history.get(myModule);
                let auxdef = {};
                try {
                    auxdef = JSON.parse(page.defaults);
                }
                catch (e) {
                    auxdef = {};
                }
                if (auxdef) {
                    for (var i = 0; i < Max3; i++) {
                        auxdef[arrDefaults[i]] = '';
                    }
                    page.defaults = JSON.stringify(auxdef);
                }
            }
        };
        //GENÉRICO: Lectura del campo de texto o combo en función de los parámetros definidos en la plantilla, si coincide el número de carácteres con el valor del parámetros ejecuta la lectura
        pda.leerItemParametros = (item, modName, modType, fields, parametros, foco) => {
            let arrObjParametros;
            let read = false;
            if ($(item).val()) {
                for (let i = 0; i < parametros.length; i++) {
                    read = flexygo.pda.readCode(parametros, $(item).val(), event);
                }
                if (read) {
                    let value = $(item).val();
                    let module = $(`[modulename=${modName}]${modType}`)[0];
                    let arrFields = fields.split(",");
                    module.additionalWhere = "";
                    arrFields.map((field, i) => {
                        i == 0 ? module.additionalWhere += `${field} = '${value}'` : module.additionalWhere += ` OR ${field} = '${value}'`;
                    });
                    module.init();
                    if (foco) {
                        if (foco[0].tagName) {
                            switch (foco[0].tagName.toLowerCase()) {
                                case 'flx-text':
                                    foco[0].querySelector('input').focus();
                                    foco[0].querySelector('input').select();
                                    break;
                                case 'button':
                                    foco[0].focus();
                                    break;
                                default:
                            }
                        }
                        else {
                            switch ($(foco)[0].tagName.toLowerCase()) {
                                case 'flx-text':
                                    $(foco)[0].querySelector('input').focus();
                                    $(foco)[0].querySelector('input').select();
                                    break;
                                case 'button':
                                    $(foco)[0].focus();
                                    break;
                                default:
                            }
                        }
                    }
                }
                else {
                    return;
                }
            }
        };
        //GENÉRICO: Revisar si hay conexión con el servidor
        pda.OnlineCheck = () => {
            return new Promise(function (resolve, reject) {
                flexygo.ajax.post('~/api/Sys', 'IsConnectionAlive', null, (response) => {
                    if (response) {
                        return resolve();
                    }
                    else {
                        return reject();
                    }
                }, (err) => {
                    return reject();
                });
            });
        };
    })(pda = flexygo.pda || (flexygo.pda = {}));
})(flexygo || (flexygo = {}));
//# sourceMappingURL=pda.js.map