var flexygo;
(function (flexygo) {
    var pda;
    (function (pda) {
        var ubicacion;
        (function (ubicacion) {
            //GENÉRICO: El evento OnKeyUp se usa para no lanzar la acción del enter sobre los focos de botón. Es necesario un OnKeyDown sólo para el tabulador
            ubicacion.readKeyTab = (e, funcname, params) => {
                if (e.keyCode == 9) {
                    e.preventDefault();
                    flexygo.pda.ubicacion[funcname].apply(flexygo.pda.ubicacion, params);
                }
                else {
                    return;
                }
            };
            //GENÉRICO: Lectura de carácteres de entrada y ejecución de la función cuando se recibe ENTER
            ubicacion.readByCharacter = (e, funcname, params) => {
                if (e.keyCode == 13) {
                    flexygo.pda.ubicacion[funcname].apply(flexygo.pda.ubicacion, params);
                }
                else {
                    return;
                }
            };
            //GENÉRICO: Cargar las descripciones de las propiedades para todos los artículos de la ubicación
            ubicacion.RellenaPropiedadesUbicacion = (IdUbicacion) => {
                let promesa = new Promise(function (resolve, reject) {
                    if (!IdUbicacion) {
                        return reject("Ubicación no recibida");
                    }
                    //Debo validar este bulto y buscar si ese codigo de barras existe entre todos los que hay
                    let proc = new flexygo.Process('SGA_PDA_dll_RellenaTablaTemporalPropiedadesUbicacion', null, null);
                    let params = [
                        { "Key": "IdAlmacen", "Value": flexygo.context.currentAlmacen },
                        { "Key": "IdUbicacion", "Value": IdUbicacion }
                    ];
                    proc.run(params, (response) => {
                        if (response) {
                            if (response.JSCode) {
                                var func = new Function(response.JSCode);
                                func.call(response.JSCode);
                                return resolve();
                            }
                            if (response.LastException && response.LastException.Message) {
                                return reject(response.LastException.Message);
                            }
                            else if (response.WarningMessage) {
                                return reject(response.WarningMessage);
                            }
                            else if (response.SuccessMessage) {
                                return resolve();
                            }
                        }
                        else {
                            return resolve();
                        }
                    });
                });
                return promesa;
            };
            //GENÉRICO: Recupera el stock de la ubicación para el artículo, lote y combinación de propiedades introducidas
            ubicacion.ObtenerStock = (IdArticulo, Lote, P1, P2, IdUbicacion) => {
                let promesa = new Promise(function (resolve, reject) {
                    //ASÍNCRONO
                    let proc = new flexygo.Process('SGA_PDA_DameStockArticuloConP', null, null);
                    let params = [
                        { 'Key': 'IdArticulo', 'Value': IdArticulo },
                        { 'Key': 'NumLote', 'Value': Lote ? Lote : "" },
                        { 'Key': 'P1', 'Value': P1 ? P1 : "" },
                        { 'Key': 'P2', 'Value': P2 ? P2 : "" },
                        { 'Key': 'IdUbicacion', 'Value': IdUbicacion }
                    ];
                    proc.run(params, (response) => {
                        if (response) {
                            if (response.JSCode) {
                                flexygo.pda.removeLock();
                                var func = new Function(response.JSCode);
                                func.call(response.JSCode);
                                return resolve(0);
                            }
                            if (response.LastException && response.LastException.Message) {
                                return reject(response.LastException.Message);
                            }
                            else if (response.WarningMessage) {
                                return reject(response.WarningMessage);
                            }
                            else if (response.SuccessMessage) {
                                return resolve(response.Data);
                            }
                        }
                        flexygo.pda.removeLock();
                    });
                });
                return promesa;
            };
            //GENÉRICO: Recupera el stock de la ubicación para el artículo, lote y combinación de propiedades introducidas en la generación de bultos
            ubicacion.ObtenerStockPicking = (IdArticulo, Lote, P1, P2, IdUbicacion) => {
                let promesa = new Promise(function (resolve, reject) {
                    //objeto para usar la vista de stock
                    let Ubicacion = new flexygo.obj.Entity(`SGA_PDA_Ubicacion`, `IdAlmacen = ${flexygo.context.currentAlmacen} AND IdUbicacion = '${IdUbicacion}'`);
                    Ubicacion.read();
                    //Filtro aplicable dependiende de los parámetros recibidos
                    let filter = `DifUbicBulto > 0 AND IdAlmacen = ${flexygo.context.currentAlmacen} AND IdUbicacion = '${IdUbicacion}' AND IdArticulo = '${IdArticulo}'`;
                    if (Lote) {
                        filter += `AND Lote = '${Lote}'`;
                    }
                    if (P1) {
                        filter += `AND P1 = '${P1}'`;
                    }
                    if (P2) {
                        filter += `AND P2 = '${P2}'`;
                    }
                    //Lanzamos vista del objeto
                    let detalle = Ubicacion.getView("VStockBulto_ComparaStockUbic", 0, 500, filter, "", null);
                    return resolve(detalle);
                });
                return promesa;
            };
            //GENÉRICO: Proponer nueva ubicación para trabajo de preparación, traspaso.
            ubicacion.NuevaUbicacion = (e) => {
                return new Promise(function (resolve, reject) {
                    //Defaults de la página
                    let myModule = $('flx-module')[0];
                    let page = flexygo.history.get(myModule);
                    let auxdef;
                    try {
                        auxdef = JSON.parse(page.defaults) ? JSON.parse(page.defaults) : {};
                    }
                    catch (e) {
                        auxdef = {};
                    }
                    //Parámetros
                    let IdDocDetalle = auxdef.IdDocDetalle ? auxdef.IdDocDetalle : 0;
                    let pbCodigo = $('flx-text[name = "pbCodigoUbicacion"]');
                    let pbCombo = $('flx-dbcombo[name = "pbComboUbicacion"]');
                    //Proceso
                    let proc = new flexygo.Process('SGA_PDA_dll_trabajo_buscanuevaubicacion', null, null);
                    let params = [{ 'Key': 'IdDocDetalle', 'Value': IdDocDetalle }];
                    flexygo.pda.addLock();
                    proc.run(params, (response) => {
                        if (response) {
                            if (response.JSCode) {
                                flexygo.pda.removeLock();
                                var func = new Function(response.JSCode);
                                func.call(response.JSCode);
                                return resolve();
                            }
                            if (response.LastException && response.LastException.Message) {
                                flexygo.msg.error(response.LastException.Message);
                                return reject(response.LastException.Message);
                            }
                            else if (response.WarningMessage) {
                                flexygo.msg.warning(response.WarningMessage);
                                return reject(response.WarningMessage);
                            }
                            else if (response.SuccessMessage) {
                                if (!response.Data || response.Data.IdDocDetalle == IdDocDetalle) {
                                    flexygo.msg.confirm('No se encuentra detalle con mismas características. ¿Desea realizar busqueda manual?', function (ret) {
                                        if (ret) {
                                            flexygo.pda.toggleMenu();
                                            flexygo.pda.ubicacion.LimpiarUbicacion();
                                            return resolve();
                                        }
                                        else {
                                            flexygo.pda.incidencia.preparaIncidencia(e, 'IdDocDetalle');
                                            return resolve();
                                        }
                                    });
                                }
                                else {
                                    //Refrescamos los módulos de la página
                                    flexygo.pda.refreshPageModules(e);
                                    //Cerramos el menú adicional
                                    flexygo.pda.toggleMenu();
                                    flexygo.pda.removeLock();
                                    return resolve();
                                }
                            }
                            else {
                                return reject();
                            }
                        }
                    });
                });
            };
            //BUSCADOR COMBOS: Lee ubicación de texto/combo y carga las descripciones de las propiedades en tabla temporal
            ubicacion.Leer = (item, event) => {
                let lectura = flexygo.pda.ubicacion.LeerUbicacionCombo(item, event);
                lectura.then(IdUbicacion => {
                    if (IdUbicacion) {
                        flexygo.pda.addLock();
                        let propiedades = flexygo.pda.ubicacion.RellenaPropiedadesUbicacion(IdUbicacion);
                        propiedades.then(function () {
                            flexygo.pda.ubicacion.CargarModulo(IdUbicacion);
                            flexygo.pda.removeLock();
                        });
                        propiedades.catch(function (error) {
                            if (error && error != "") {
                                flexygo.msg.warning(error);
                            }
                        });
                    }
                });
                lectura.catch(error => {
                    if (error && error != "") {
                        flexygo.msg.warning(error);
                    }
                });
            };
            //BUSCADOR COMBOS: Método de lectura por campos IdUbicacion y Codigo de objeto SGA_PDA_Ubicacion, para dupla flx-text y flx-dbcombo.
            ubicacion.LeerUbicacionCombo = (item, event) => {
                let promesa = new Promise(function (resolve, reject) {
                    //Parámetros
                    let params = $(`.param`);
                    let pbCodigo = $('flx-text[name = "pbCodigoUbicacion"]');
                    let pbCombo = $('flx-dbcombo[name = "pbComboUbicacion"]');
                    let pbNivel = $('flx-text[name = "pbNivel"]');
                    //Valor de búsqueda del campo de texto o del combo
                    let valorBusqueda = ((item.tagName).toLowerCase() == "flx-text") ? pbCodigo.val() : pbCombo.val();
                    if (!valorBusqueda) {
                        return resolve();
                    }
                    ;
                    //Defaults de la página
                    let myModule = $('flx-module')[0];
                    let page = flexygo.history.get(myModule);
                    let auxdef;
                    try {
                        auxdef = JSON.parse(page.defaults) ? JSON.parse(page.defaults) : {};
                    }
                    catch (e) {
                        auxdef = {};
                    }
                    //Campo que indica si la lectura se ha llevado a cabo
                    let read = false;
                    //Si ha cambiado el valor del combo. Evitamos lanzar la búsqueda con el mismo valor.
                    if (auxdef.valorBusqueda != valorBusqueda) {
                        //En caso de recibir parámetro con longitudes a tener en cuenta, y se trata del campo de texto, se verifica si se ha legeado al tamaño del parámetro
                        read = params ? (((item.tagName).toLowerCase() == "flx-text") ? flexygo.pda.readCode(params, valorBusqueda, event) : true) : true;
                    }
                    //Si damos la entrada como buena
                    if (read) {
                        flexygo.pda.addLock();
                        //Buscamos ubicación por Id o código
                        let UbicacionEnt = new flexygo.obj.Entity(`SGA_PDA_Ubicacion`, `IdAlmacen = ${flexygo.context.currentAlmacen} AND (IdUbicacion = '${valorBusqueda}' OR Codigo = '${valorBusqueda}')`);
                        UbicacionEnt.read();
                        //No hay registro
                        if (!UbicacionEnt.data.IdDoc.Value) {
                            return reject("No se ha encontrado ninguna ubicación que coincida con el criterio de búsqueda introducido.");
                        }
                        //Valor por defecto para evitar lanzar búsquedas sin cambio de valor
                        auxdef.valorBusqueda = valorBusqueda;
                        page.defaults = JSON.stringify(auxdef);
                        //Relación de campo texto/combo
                        if ((item.tagName).toLowerCase() == "flx-text" && pbCombo[0]) {
                            pbCombo[0].additionalWhere = `IdUbicacion = '${UbicacionEnt.data.IdUbicacion.Value}'`;
                            pbCombo[0].refresh();
                            pbCombo.val(UbicacionEnt.data.IdUbicacion.Value);
                        }
                        else {
                            pbCodigo.val(UbicacionEnt.data.Codigo.Value);
                        }
                        //Si existe el botón de Nivel hay que actualizarlo
                        flexygo.pda.ubicacion.LoadBadgeNivel(UbicacionEnt.data.Nivel.Value);
                        //Foco automático por propiedad tabindex en los campos
                        flexygo.pda.setAutomaticFocus(item);
                        flexygo.pda.removeLock();
                        return resolve(UbicacionEnt.data.IdUbicacion.Value);
                    }
                    else {
                        return resolve();
                    }
                });
                return promesa;
            };
            //BUSCADOR COMBOS: Botón de limpieza del selector de ubicaciones/niveles
            ubicacion.LimpiarUbicacion = () => {
                //Controles
                let pbCodigo = $('flx-text[name = "pbCodigoUbicacion"]');
                let pbCombo = $('flx-dbcombo[name = "pbComboUbicacion"]');
                let pbNivel = $('flx-text[name = "pbNivel"]');
                //Campos de ubicación
                pbCodigo.val(null);
                pbCombo.val(null);
                //Encontramos módulos a visualizar y los limpiamos
                $("flx-module.LecturaUbicacionDatos").find('flx-list, flx-view').map(function (indice, modulo) {
                    let module = $(modulo)[0];
                    module.additionalWhere = "1 = 0";
                    module.init();
                });
                //Defaults de la página
                let myModule = $('flx-module')[0];
                let page = flexygo.history.get(myModule);
                let auxdef;
                try {
                    auxdef = JSON.parse(page.defaults) ? JSON.parse(page.defaults) : {};
                }
                catch (e) {
                    auxdef = {};
                }
                auxdef.valorBusqueda = "";
                page.defaults = JSON.stringify(auxdef);
                //Limpiamos el nivel
                flexygo.pda.ubicacion.LoadBadgeNivel("0");
                //Foco
                pbCodigo[0].querySelector("input").focus();
            };
            //BUSCADOR COMBOS: carga el módulo de datos
            ubicacion.CargarModulo = (IdUbicacion) => {
                //Encontramos módulos a visualizar y los cargamos
                $("flx-module.LecturaUbicacionDatos").find('flx-list, flx-view').map(function (indice, modulo) {
                    let module = $(modulo)[0];
                    module.additionalWhere = `IdAlmacen = '${flexygo.context.currentAlmacen}' AND IdUbicacion = '${IdUbicacion}'`;
                    module.init();
                });
            };
            //BUSCADOR SELECTOR DE NIVEL: crea el diálogo de selección de nivel
            ubicacion.MostrarNiveles = (item) => {
                //Cerramos diálogo previo en caso de existir
                if ($("#dialog")) {
                    $("#dialog").remove();
                }
                //Parámetros
                let pbCombo = $('flx-dbcombo[name = "pbComboUbicacion"]');
                //Si no hay selección de ubicación no hacemos nada
                if (!pbCombo.val()) {
                    flexygo.msg.warning("Seleccione una ubicación.");
                    return;
                }
                //Cuerpo del selector
                $("body").append(`<div class='d-none col-12 customDialog' id='dialog' title='Seleccione Nivel'></div>`);
                //Clonamos módulo y precargamos con la selección
                let module = $(`[modulename=SGA_PDA_m_Ubicacion_Nivel]flx-list`)[0];
                let clone = module.cloneNode();
                clone.additionalWhere = `UbicacionOrigen = '${pbCombo.val()}'`;
                ;
                //Creación del contenido del selector
                document.body.querySelector("#dialog").appendChild(clone);
                clone.init();
                $('#dialog').switchClass("d-none", "d-block");
                $('#dialog').dialog({
                    minWidth: 300,
                    width: $("#mainContent").width(),
                    position: ['center', 20],
                    maxHeight: $("#mainContent").height(),
                });
            };
            //BUSCADOR SELECTOR DE NIVEL: selección de nivel
            ubicacion.SeleccionaNivel = (e, IdUbicacion) => {
                //Parámetros
                let pbCombo = $('flx-dbcombo[name = "pbComboUbicacion"]');
                //Actualizamos el valor del combo si cambia la selección
                if (pbCombo && pbCombo.length == 1 && IdUbicacion && pbCombo.val() != IdUbicacion) {
                    pbCombo.val(IdUbicacion);
                    pbCombo.change();
                    $('#dialog').dialog('close');
                }
            };
            //BUSCADOR SELECTOR DE NIVEL: actualiza badge
            ubicacion.LoadBadgeNivel = (Nivel) => {
                //Campo
                let pbNivel = $('[name = "pbNivel"]');
                //Actualizamos con el texto
                if (pbNivel && pbNivel.length == 1 && Nivel) {
                    pbNivel.text(Nivel);
                }
            };
        })(ubicacion = pda.ubicacion || (pda.ubicacion = {}));
    })(pda = flexygo.pda || (flexygo.pda = {}));
})(flexygo || (flexygo = {}));
//# sourceMappingURL=ubicacion.js.map